@@ -10,4 +10,6 @@
 #undef ENABLE_MD4
 #undef ENABLE_GOST
 #undef ENABLE_ADLER32
-#undef ENABLE_SHA256
+#undef ENABLE_SHA256_SHA224
+#undef ENABLE_SHA512_SHA384
+#undef ENABLE_WHIRLPOOL
