@@ -20,15 +20,38 @@
 
 
 
-#include <ctype.h>
 #include "libdefs.h"
 
+#ifdef WIN32
+/* Provided by Stefan Hetzl <shetzl@chello.at>
+ * in order for isxdigit to work on cygwin.
+ */
+static char hexdigits[] = { '0', '1', '2', '3', '4',
+			'5', '6', '7', '8', '9',
+			'a', 'b', 'c', 'd', 'e', 'f',
+			'A', 'B', 'C', 'D', 'E', 'F' } ;
+
+static int ishexdigit (char d)
+{
+	int i;
+
+	for (i = 0 ; i < 22 ; i++)
+		if (d == hexdigits[i]) 
+			return -1;
+
+	return 0 ;
+}
+#else
+# include <ctype.h>
+# define ishexdigit isxdigit
+#endif
+
 static int check_hex(char *given_chain, int len)
 {
 	int i;
 
 	for (i = 0; i < len; i++)
-		if (isxdigit(given_chain[i]) == 0)
+		if (ishexdigit(given_chain[i]) == 0)
 			return -1;
 
 	return 0;
