@@ -16,6 +16,9 @@
  * needed on buffers full of bytes, and then call MD5Final, which
  * will fill a supplied 16-byte array with the digest.
  */
+
+#ifdef ENABLE_MD5
+
 #include "mhash_md5.h"
 
 #ifndef WORDS_BIGENDIAN
@@ -105,7 +108,7 @@ void MD5Update(struct MD5Context *ctx, unsigned char const *buf, unsigned len)
  * Final wrapup - pad to 64-byte boundary with the bit pattern 
  * 1 0* (64-bit count of bits processed, MSB-first)
  */
-void MD5Final(unsigned char* digest, struct MD5Context *ctx)
+void MD5Final(struct MD5Context *ctx, unsigned char* digest)
 {
     unsigned int count;
     unsigned char *p;
@@ -247,3 +250,5 @@ void MD5Transform(word32 buf[4], word32 const in[16])
     buf[2] += c;
     buf[3] += d;
 }
+
+#endif /* ENABLE_MD5 */
