@@ -4,7 +4,7 @@
 #include "libdefs.h"
 
 void mhash_clear_adler32(word32 * adler);
-void mhash_get_adler32(void* ret, const word32 * adler);
+void mhash_get_adler32( const word32 * adler, void* ret);
 void mhash_adler32(word32 * adler, const void *, int);
 
 #endif
