@@ -20,7 +20,14 @@ enum hashid {
 	MHASH_TIGER160,
 	MHASH_MD4,
 	MHASH_SHA256,
-	MHASH_ADLER32
+	MHASH_ADLER32,
+	MHASH_SHA224,
+	MHASH_SHA512,
+	MHASH_SHA384,
+	MHASH_WHIRLPOOL,
+	MHASH_RIPEMD128,
+	MHASH_RIPEMD256,
+	MHASH_RIPEMD320,
 };
 
 enum keygenid {
